@@ -403,7 +403,7 @@ class AbstractOUProblem(AbstractProblem):
         self.strategy = Strategy.OU
         self.levels = kwargs.get('levels', EAConstants.LEVELS)
         self._reference = kwargs.get('reference', None)
-        self.twostep = kwargs.get('twostep', True)
+        self.twostep = kwargs.get('twostep', False)
         self._partial_solution = kwargs.get('partial_solution', dict())
 
     def decode(self, candidate):
